//
//      tardy - a tar post-processor
//      Copyright (C) 1998, 1999, 2003, 2008, 2009 Peter Miller
//
//      This program is free software; you can redistribute it and/or modify
//      it under the terms of the GNU General Public License as published by
//      the Free Software Foundation; either version 3 of the License, or
//      (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#ifndef COMMON_TAR_INPUT_FILTER_GROUP_NUMBR_H
#define COMMON_TAR_INPUT_FILTER_GROUP_NUMBR_H

#include <libtardy/tar/input/filter.h>

/**
  * The tar_input_filter_group_number class is used to represent a
  * filter which replaces the Group ID field in all the file headers of
  * a tar archive.
  */
class tar_input_filter_group_number:
    public tar_input_filter
{
public:
    /**
      * The destructor.
      */
    virtual ~tar_input_filter_group_number();

    /**
      * The constructor.
      *
      * \param deeper
      *     The deeper argument points to the input stream to be filtered.
      * \param gid
      *     The gid parameter indicates the group ID to be placed into
      *     each file header.
      */
    tar_input_filter_group_number(tar_input *deeper, long gid);

    // See base class for documentation.
    virtual int read_header(tar_header &);

private:
    /**
      * The gid instance variable is used to remember the Group ID to
      * (re)place into each filter header.
      */
    long gid;

    /**
      * The default constructor.  Do not use.
      */
    tar_input_filter_group_number();

    /**
      * The copy constructor.  Do not use.
      */
    tar_input_filter_group_number(const tar_input_filter_group_number &);

    /**
      * The assignment operator.  Do not use.
      */
    tar_input_filter_group_number &operator = (
        const tar_input_filter_group_number &);
};

#endif // COMMON_TAR_INPUT_FILTER_GROUP_NUMBR_H
