#!/bin/sh
#
#       tardy - a tar post-processor
#       Copyright (C) 1995, 1999, 2008 Peter Miller
#
#       This program is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 3 of the License, or
#       (at your option) any later version.
#
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#
#       You should have received a copy of the GNU General Public License
#       along with this program. If not, see
#       <http://www.gnu.org/licenses/>.
#

umask 022

USER=${USER:-${LOGNAME:-`whoami`}}

work=/tmp/$$
PAGER=cat
export PAGER

here=`pwd`
if test $? -ne 0 ; then exit 1; fi

if test "$1" != "" ; then bin="$here/$1/bin"; else bin="$here/bin"; fi

fail()
{
        set +x
        echo 'FAILED test of the -nodir functionality' 1>&2
        cd $here
        find $work -type d -user $USER -exec chmod u+w {} \;
        rm -rf $work
        exit 1
}
pass()
{
        set +x
        echo PASSED 1>&2
        cd $here
        find $work -type d -user $USER -exec chmod u+w {} \;
        rm -rf $work
        exit 0
}
trap \"fail\" 1 2 3 15

mkdir $work
if test $? -ne 0 ; then fail; fi
cd $work
if test $? -ne 0 ; then fail; fi

#
# test the -nodir functionality
#
mkdir a a/b
if test $? -ne 0 ; then fail; fi
cat > a/b/c << 'fubar'
something short
fubar
if test $? -ne 0 ; then fail; fi

tar cf test1 a
if test $? -ne 0 ; then fail; fi

$bin/tardy -nodir test1 test2
if test $? -ne 0 ; then fail; fi

$bin/tardy -list test2 /dev/null 2> test3
if test $? -ne 0 ; then fail; fi

awk '{print $4 " " $5 }' < test3 > test.out
if test $? -ne 0 ; then fail; fi

cat > test.ok << 'fubar'
16 a/b/c
fubar
if test $? -ne 0 ; then fail; fi

diff test.ok test.out
if test $? -ne 0 ; then fail; fi

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass
